'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var tslib = require('tslib');
var coreComponentsShared = require('@alfalab/core-components-shared/cssm');
var consts = require('./consts.js');

function getDefaultObserveTarget() {
    return document.head;
}
function getColorByToken(token) {
    return getComputedStyle(document.documentElement).getPropertyValue(token);
}
var getSizes = (function () {
    var COMMON_SIZES = {
        lineWidth: 6,
        nodeRing: 0,
        nodeCore: 12,
    };
    var cachedSize;
    return function () {
        if (cachedSize) {
            return cachedSize;
        }
        if (window.matchMedia('(min-width: 600px)').matches) {
            cachedSize = {
                elementSizes: tslib.__assign(tslib.__assign({}, COMMON_SIZES), { nodeRadius: 32 }),
                width: 240,
                height: 240,
            };
        }
        else if (window.matchMedia('(min-width: 390px)').matches) {
            cachedSize = {
                elementSizes: tslib.__assign(tslib.__assign({}, COMMON_SIZES), { nodeRadius: 43 }),
                width: 322,
                height: 322,
            };
        }
        else if (window.matchMedia('(min-width: 360px)').matches) {
            cachedSize = {
                elementSizes: tslib.__assign(tslib.__assign({}, COMMON_SIZES), { nodeRadius: 38 }),
                width: 292,
                height: 292,
            };
        }
        else {
            cachedSize = {
                elementSizes: tslib.__assign(tslib.__assign({}, COMMON_SIZES), { nodeRadius: 32 }),
                width: 240,
                height: 240,
            };
        }
        return cachedSize;
    };
})();
function getTheme(dimens) {
    var _a;
    var baseColors = {
        primary: getColorByToken(consts.OBSERVABLE_TOKENS.PRIMARY),
        bg: getColorByToken(consts.OBSERVABLE_TOKENS.BG),
        ringBg: getColorByToken(consts.OBSERVABLE_TOKENS.RING_BG_INITIAL),
        hover: {
            inner: getColorByToken(consts.OBSERVABLE_TOKENS.HOVER_INNER),
            outer: getColorByToken(consts.OBSERVABLE_TOKENS.HOVER_OUTER),
        },
    };
    return _a = {},
        _a[consts.THEME_STATE.INITIAL] = {
            colors: tslib.__assign(tslib.__assign({}, baseColors), { accent: getColorByToken(consts.OBSERVABLE_TOKENS.ACCENT_INITIAL), selectedRingBg: getColorByToken(consts.OBSERVABLE_TOKENS.SELECTED_RING_BG_INITIAL) }),
            dimens: dimens,
        },
        _a[consts.THEME_STATE.SUCCESS] = {
            colors: tslib.__assign(tslib.__assign({}, baseColors), { accent: getColorByToken(consts.OBSERVABLE_TOKENS.ACCENT_SUCCESS), selectedRingBg: getColorByToken(consts.OBSERVABLE_TOKENS.SELECTED_RING_BG_SUCCESS) }),
            dimens: dimens,
        },
        _a[consts.THEME_STATE.FAILURE] = {
            colors: tslib.__assign(tslib.__assign({}, baseColors), { accent: getColorByToken(consts.OBSERVABLE_TOKENS.ACCENT_FAILURE), selectedRingBg: getColorByToken(consts.OBSERVABLE_TOKENS.SELECTED_RING_BG_FAILURE) }),
            dimens: dimens,
        },
        _a;
}
function getPatternLockTestIds(dataTestId) {
    return {
        patternLock: dataTestId,
        forgotCodeBtn: coreComponentsShared.getDataTestId(dataTestId, 'forgot-code-btn'),
        error: coreComponentsShared.getDataTestId(dataTestId, 'error'),
        message: coreComponentsShared.getDataTestId(dataTestId, 'message'),
    };
}

exports.getColorByToken = getColorByToken;
exports.getDefaultObserveTarget = getDefaultObserveTarget;
exports.getPatternLockTestIds = getPatternLockTestIds;
exports.getSizes = getSizes;
exports.getTheme = getTheme;
